Opbeat for Python
=================

.. image:: https://api.travis-ci.org/opbeat/opbeat_python.svg?branch=master
    :target: https://travis-ci.org/opbeat/opbeat_python
    :alt: Build Status
    
.. image:: https://img.shields.io/pypi/v/opbeat.svg?style=flat
    :target: https://pypi.python.org/pypi/opbeat/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/opbeat.svg?style=flat
    :target: https://pypi.python.org/pypi/opbeat/
    :alt: Supported Python versions


This is the official Python module for `Opbeat <https://opbeat.com/>`_.

It provides full out-of-the-box support for many of the popular frameworks,
including Django, and Flask. Opbeat also includes drop-in support for any
WSGI-compatible web application.

Your application doesn't live on the web? No problem! Opbeat is easy to use in
any Python application.


Documentation
-------------

* `Documentation overview <https://opbeat.com/docs/topics/python/>`_
* `Get started with Django <https://opbeat.com/docs/articles/get-started-with-django/>`_
* `Get started with Flask <https://opbeat.com/docs/articles/get-started-with-flask/>`_
* `Get started with a custom Python stack <https://opbeat.com/docs/articles/get-started-with-a-custom-python-stack/>`_


License
-------

BSD-3-Clause


Made with ♥️ and ☕️ by Opbeat and our community.
